==> ui-framework-4.17.9-sources.jar: io/intino/alexandria/ui/displays/templates/AbstractMicroSiteExamplesMold.java <==
package io.intino.alexandria.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.alexandria.ui.*;

import io.intino.alexandria.UiFrameworkBox;

import io.intino.alexandria.ui.displays.templates.*;






import io.intino.alexandria.ui.displays.items.*;
import io.intino.alexandria.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractMicroSiteExamplesMold<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public _7_1_0652280648 _7_1_0652280648;
	public MicroSiteExamplesMold._7_1_0652280648. _8_2_025654523 _8_2_025654523;
	public MicroSiteExamplesMold._7_1_0652280648._8_2_025654523. _9_3_0308355687 _9_3_0308355687;
	public MicroSiteExamplesMold._7_1_0652280648._8_2_025654523. _10_3_0851332079 _10_3_0851332079;
	public MicroSiteExamplesMold._7_1_0652280648._8_2_025654523._10_3_0851332079. Site site;
	public MicroSiteExamplesMold._7_1_0652280648._8_2_025654523._10_3_0851332079. _12_4_031194112 _12_4_031194112;
	public MicroSiteExamplesMold._7_1_0652280648._8_2_025654523._10_3_0851332079._12_4_031194112. _12_12_137989795 _12_12_137989795;

    public AbstractMicroSiteExamplesMold(B box) {
        super(box);
        id("microSiteExamplesMold");
    }

    @Override
	public void init() {
		super.init();
		if (_7_1_0652280648 == null) _7_1_0652280648 = register(new _7_1_0652280648(box()).<_7_1_0652280648>id("a1983007800").owner(AbstractMicroSiteExamplesMold.this));
		if (_7_1_0652280648 != null) _8_2_025654523 = _7_1_0652280648._8_2_025654523;
		if (_8_2_025654523 != null) _9_3_0308355687 = _7_1_0652280648._8_2_025654523._9_3_0308355687;
		if (_8_2_025654523 != null) _10_3_0851332079 = _7_1_0652280648._8_2_025654523._10_3_0851332079;
		if (_10_3_0851332079 != null) site = _7_1_0652280648._8_2_025654523._10_3_0851332079.site;
		if (_10_3_0851332079 != null) _12_4_031194112 = _7_1_0652280648._8_2_025654523._10_3_0851332079._12_4_031194112;
		if (_12_4_031194112 != null) _12_12_137989795 = _7_1_0652280648._8_2_025654523._10_3_0851332079._12_4_031194112._12_12_137989795;
	}

    @Override
    public void remove() {
        super.remove();
	    if (_7_1_0652280648 != null) _7_1_0652280648.unregister();
	}

	public class _7_1_0652280648 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public MicroSiteExamplesMold._7_1_0652280648. _8_2_025654523 _8_2_025654523;

		public _7_1_0652280648(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_8_2_025654523 == null) _8_2_025654523 = register(new _8_2_025654523(box()).<_8_2_025654523>id("a500564523").owner(AbstractMicroSiteExamplesMold.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (_8_2_025654523 != null) _8_2_025654523.unregister();
		}

		public class _8_2_025654523 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public MicroSiteExamplesMold._7_1_0652280648._8_2_025654523. _9_3_0308355687 _9_3_0308355687;
			public MicroSiteExamplesMold._7_1_0652280648._8_2_025654523. _10_3_0851332079 _10_3_0851332079;

			public _8_2_025654523(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_9_3_0308355687 == null) _9_3_0308355687 = register(new _9_3_0308355687(box()).<_9_3_0308355687>id("a_1742901962").owner(AbstractMicroSiteExamplesMold.this));
				if (_10_3_0851332079 == null) _10_3_0851332079 = register(new _10_3_0851332079(box()).<_10_3_0851332079>id("a1195753113").owner(AbstractMicroSiteExamplesMold.this));
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (_9_3_0308355687 != null) _9_3_0308355687.unregister();
				if (_10_3_0851332079 != null) _10_3_0851332079.unregister();
			}

			public class _9_3_0308355687 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public _9_3_0308355687(B box) {
					super(box);
					_value("No facets");
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
				    super.unregister();
				}
			}

			public class _10_3_0851332079 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public MicroSiteExamplesMold._7_1_0652280648._8_2_025654523._10_3_0851332079. Site site;
				public MicroSiteExamplesMold._7_1_0652280648._8_2_025654523._10_3_0851332079. _12_4_031194112 _12_4_031194112;

				public _10_3_0851332079(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (site == null) site = register(new Site(box()).<Site>id("a_524828993").owner(AbstractMicroSiteExamplesMold.this));
					if (_12_4_031194112 == null) _12_4_031194112 = register(new _12_4_031194112(box()).<_12_4_031194112>id("a_1360632878").owner(AbstractMicroSiteExamplesMold.this));
				}

				@Override
				public void unregister() {
				    super.unregister();
					if (site != null) site.unregister();
					if (_12_4_031194112 != null) _12_4_031194112.unregister();
				}

				public class Site extends io.intino.alexandria.ui.displays.components.MicroSite<io.intino.alexandria.ui.displays.notifiers.MicroSiteNotifier, B>  {

					public Site(B box) {
						super(box);
						_site(AbstractMicroSiteExamplesMold.class.getResource("/data/microsite.zip"));
					}

					@Override
					public void init() {
						super.init();
					}

					@Override
					public void unregister() {
					    super.unregister();
					}
				}

				public class _12_4_031194112 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
					public MicroSiteExamplesMold._7_1_0652280648._8_2_025654523._10_3_0851332079._12_4_031194112. _12_12_137989795 _12_12_137989795;

					public _12_4_031194112(B box) {
						super(box);
					}

					@Override
					public void init() {
						super.init();
						if (_12_12_137989795 == null) _12_12_137989795 = register(new _12_12_137989795(box()).<_12_12_137989795>id("a1019872708").owner(AbstractMicroSiteExamplesMold.this));
					}

					@Override
					public void unregister() {
					    super.unregister();
						if (_12_12_137989795 != null) _12_12_137989795.unregister();
					}

					public class _12_12_137989795 extends io.intino.alexandria.ui.displays.components.TextCode<io.intino.alexandria.ui.displays.notifiers.TextCodeNotifier, B>  {

						public _12_12_137989795(B box) {
							super(box);
							_value("MicroSite(site=empty) site");
						}

						@Override
						public void init() {
							super.init();
						}

						@Override
						public void unregister() {
						    super.unregister();
						}
					}
				}
			}
		}
	}
}

==> ui-framework-4.28.15-sources.jar: io/intino/alexandria/ui/displays/templates/AbstractMicroSiteExamplesMold.java <==
package io.intino.alexandria.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.alexandria.ui.*;

import io.intino.alexandria.UiFrameworkBox;

import io.intino.alexandria.ui.displays.templates.*;






import io.intino.alexandria.ui.displays.items.*;
import io.intino.alexandria.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractMicroSiteExamplesMold<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public _7_1_11847497954 _7_1_11847497954;
	public MicroSiteExamplesMold._7_1_11847497954. _8_2_025654523 _8_2_025654523;
	public MicroSiteExamplesMold._7_1_11847497954._8_2_025654523. _9_3_0308355687 _9_3_0308355687;
	public MicroSiteExamplesMold._7_1_11847497954._8_2_025654523. _10_3_0851332079 _10_3_0851332079;
	public MicroSiteExamplesMold._7_1_11847497954._8_2_025654523._10_3_0851332079. Site site;
	public MicroSiteExamplesMold._7_1_11847497954._8_2_025654523._10_3_0851332079. _12_4_031194112 _12_4_031194112;
	public MicroSiteExamplesMold._7_1_11847497954._8_2_025654523._10_3_0851332079._12_4_031194112. _12_12_137989795 _12_12_137989795;

	public AbstractMicroSiteExamplesMold(B box) {
		super(box);
		id("microSiteExamplesMold");
	}

	@Override
	public void init() {
		super.init();
		if (_7_1_11847497954 == null) _7_1_11847497954 = register(new _7_1_11847497954(box()).<_7_1_11847497954>id("a_1371046148").owner(AbstractMicroSiteExamplesMold.this));
		if (_7_1_11847497954 != null) _8_2_025654523 = _7_1_11847497954._8_2_025654523;
		if (_8_2_025654523 != null) _9_3_0308355687 = _7_1_11847497954._8_2_025654523._9_3_0308355687;
		if (_8_2_025654523 != null) _10_3_0851332079 = _7_1_11847497954._8_2_025654523._10_3_0851332079;
		if (_10_3_0851332079 != null) site = _7_1_11847497954._8_2_025654523._10_3_0851332079.site;
		if (_10_3_0851332079 != null) _12_4_031194112 = _7_1_11847497954._8_2_025654523._10_3_0851332079._12_4_031194112;
		if (_12_4_031194112 != null) _12_12_137989795 = _7_1_11847497954._8_2_025654523._10_3_0851332079._12_4_031194112._12_12_137989795;
	}

	@Override
	public void remove() {
		super.remove();
		if (_7_1_11847497954 != null) _7_1_11847497954.unregister();
	}

	public class _7_1_11847497954 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public MicroSiteExamplesMold._7_1_11847497954. _8_2_025654523 _8_2_025654523;

		public _7_1_11847497954(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_8_2_025654523 == null) _8_2_025654523 = register(new _8_2_025654523(box()).<_8_2_025654523>id("a500564523").owner(AbstractMicroSiteExamplesMold.this));
		}

		@Override
		public void unregister() {
			super.unregister();
			if (_8_2_025654523 != null) _8_2_025654523.unregister();
		}

		public class _8_2_025654523 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public MicroSiteExamplesMold._7_1_11847497954._8_2_025654523. _9_3_0308355687 _9_3_0308355687;
			public MicroSiteExamplesMold._7_1_11847497954._8_2_025654523. _10_3_0851332079 _10_3_0851332079;

			public _8_2_025654523(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_9_3_0308355687 == null) _9_3_0308355687 = register(new _9_3_0308355687(box()).<_9_3_0308355687>id("a_1742901962").owner(AbstractMicroSiteExamplesMold.this));
				if (_10_3_0851332079 == null) _10_3_0851332079 = register(new _10_3_0851332079(box()).<_10_3_0851332079>id("a1195753113").owner(AbstractMicroSiteExamplesMold.this));
			}

			@Override
			public void unregister() {
				super.unregister();
				if (_9_3_0308355687 != null) _9_3_0308355687.unregister();
				if (_10_3_0851332079 != null) _10_3_0851332079.unregister();
			}

			public class _9_3_0308355687 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public _9_3_0308355687(B box) {
					super(box);
					_value("No facets");
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
					super.unregister();
				}
			}

			public class _10_3_0851332079 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public MicroSiteExamplesMold._7_1_11847497954._8_2_025654523._10_3_0851332079. Site site;
				public MicroSiteExamplesMold._7_1_11847497954._8_2_025654523._10_3_0851332079. _12_4_031194112 _12_4_031194112;

				public _10_3_0851332079(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (site == null) site = register(new Site(box()).<Site>id("a_524828993").owner(AbstractMicroSiteExamplesMold.this));
					if (_12_4_031194112 == null) _12_4_031194112 = register(new _12_4_031194112(box()).<_12_4_031194112>id("a_1360632878").owner(AbstractMicroSiteExamplesMold.this));
				}

				@Override
				public void unregister() {
					super.unregister();
					if (site != null) site.unregister();
					if (_12_4_031194112 != null) _12_4_031194112.unregister();
				}

				public class Site extends io.intino.alexandria.ui.displays.components.MicroSite<io.intino.alexandria.ui.displays.notifiers.MicroSiteNotifier, B>  {

					public Site(B box) {
						super(box);
						_site(AbstractMicroSiteExamplesMold.class.getResource("/data/microsite.zip"));
					}

					@Override
					public void init() {
						super.init();
					}

					@Override
					public void unregister() {
						super.unregister();
					}
				}

				public class _12_4_031194112 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
					public MicroSiteExamplesMold._7_1_11847497954._8_2_025654523._10_3_0851332079._12_4_031194112. _12_12_137989795 _12_12_137989795;

					public _12_4_031194112(B box) {
						super(box);
					}

					@Override
					public void init() {
						super.init();
						if (_12_12_137989795 == null) _12_12_137989795 = register(new _12_12_137989795(box()).<_12_12_137989795>id("a1019872708").owner(AbstractMicroSiteExamplesMold.this));
					}

					@Override
					public void unregister() {
						super.unregister();
						if (_12_12_137989795 != null) _12_12_137989795.unregister();
					}

					public class _12_12_137989795 extends io.intino.alexandria.ui.displays.components.TextCode<io.intino.alexandria.ui.displays.notifiers.TextCodeNotifier, B>  {

						public _12_12_137989795(B box) {
							super(box);
							_value("MicroSite(site=empty) site");
						}

						@Override
						public void init() {
							super.init();
						}

						@Override
						public void unregister() {
							super.unregister();
						}
					}
				}
			}
		}
	}
}
